==> airflow_tools-0.7.6-py3-none-any.whl: airflow_tools/filesystems/impl/local_filesystem.py <==
import shutil
from io import BytesIO
from pathlib import Path

from airflow.hooks.filesystem import FSHook

from airflow_tools.filesystems.filesystem_protocol import FilesystemProtocol


class LocalFilesystem(FilesystemProtocol):
    def __init__(self, hook: FSHook):
        self.hook = hook

    def read(self, path: str) -> bytes:
        return (Path(self.hook.get_path()) / path).read_bytes()

    def write(self, data: str | bytes | BytesIO, path: str):
        if isinstance(data, str):
            data = data.encode()
        elif isinstance(data, BytesIO):
            data = data.getvalue()
        (Path(self.hook.get_path()) / path).write_bytes(data)

    def delete_file(self, path: str):
        path_to_delete = Path(self.hook.get_path()) / path
        path_to_delete.unlink()

    def create_prefix(self, prefix: str):
        path_to_create = Path(self.hook.get_path()) / prefix
        path_to_create.mkdir(parents=True, exist_ok=True)

    def delete_prefix(self, prefix: str):
        path_to_delete = Path(self.hook.get_path()) / prefix
        shutil.rmtree(str(path_to_delete))

    def check_file(self, path: str) -> bool:
        path_to_check = Path(self.hook.get_path()) / path
        return path_to_check.is_file()

    def check_prefix(self, prefix: str) -> bool:
        path_to_check = Path(self.hook.get_path()) / prefix
        return path_to_check.exists()

    def list_files(self, prefix: str) -> list[str]:
        path_to_list = Path(self.hook.get_path()) / prefix
        return [str(file) for file in path_to_list.glob("*") if file.is_file()]

==> airflow_tools-0.8.6-py3-none-any.whl: airflow_tools/filesystems/impl/local_filesystem.py <==
import shutil
from io import BytesIO
from pathlib import Path

from airflow.hooks.filesystem import FSHook

from airflow_tools.filesystems.filesystem_protocol import FilesystemProtocol


class LocalFilesystem(FilesystemProtocol):
    def __init__(self, hook: FSHook):
        self.hook = hook

    def read(self, path: str) -> bytes:
        return (Path(self.hook.get_path()) / path).read_bytes()

    def write(self, data: str | bytes | BytesIO, path: str):
        if isinstance(data, str):
            data = data.encode()
        elif isinstance(data, BytesIO):
            data = data.getvalue()
        (Path(self.hook.get_path()) / path).write_bytes(data)

    def delete_file(self, path: str):
        path_to_delete = Path(self.hook.get_path()) / path
        path_to_delete.unlink()

    def create_prefix(self, prefix: str):
        path_to_create = Path(self.hook.get_path()) / prefix
        path_to_create.mkdir(parents=True, exist_ok=True)

    def delete_prefix(self, prefix: str):
        path_to_delete = Path(self.hook.get_path()) / prefix
        shutil.rmtree(str(path_to_delete))

    def check_file(self, path: str) -> bool:
        path_to_check = Path(self.hook.get_path()) / path
        return path_to_check.exists() and path_to_check.is_file()

    def check_prefix(self, prefix: str) -> bool:
        path_to_check = Path(self.hook.get_path()) / prefix
        return path_to_check.exists() and path_to_check.is_dir()

    def list_files(self, prefix: str) -> list[str]:
        path_to_list = Path(self.hook.get_path()) / prefix
        return [str(file) for file in path_to_list.glob("*") if file.is_file()]
